"power.longtest" in nice layout.## S3 method for class 'power.longtest':
print(x, \dots)"power.longtest".power.longtest object is just a named list of numbers and
character strings, supplemented with method and note
elements. The method is displayed as a title, the note
as a footnote, and the remaining elements are given in an aligned
liu.liang.linear.power,
diggle.linear.power,
lmmpower,